# test_report.html

Report generated on 20-Mar-2026 at 15:35:58 by pytest-html v4.2.0

## Environment

## Summary

103 tests took 00:00:11.

(Un)check the boxes to filter the results.

There are still tests running.
Reload this page to get the latest results!
0 Failed, 103 Passed, 0 Skipped, 0 Expected failures, 0 Unexpected passes, 0 Errors, 0 Reruns 0 Retried,
/

Result | Test | Duration | Links
--- | --- | --- | ---